@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/arc.c,v 4.25 2000/05/20 19:21:13 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/arc.c,v 4.26 2000/07/18 18:57:55 william Exp $
  */
 
 #define _INCLUDE_FROM_ARC_C_
@@ -1511,8 +1511,6 @@ int GetCenter(Ax, Ay, Cx, Cy, Bx, By, pcx, pcy, pdir)
    return TRUE;
 }
 
-static XComposeStatus c_stat;
- 
 static
 void HighLightInContinueArc(drawing_arc, OrigX, OrigY, saved_x, saved_y,
       ltx, lty, pw, ph, angle1, angle2, pdx, pdy, pradius, show_measure_cursor,
@@ -1651,14 +1649,7 @@ void ContinueArc(OrigX, OrigY)
       } else if (input.type == MotionNotify || input.type == KeyPress ||
             input.type == KeyRelease) {
          if (input.type == KeyPress) {
-            KeySym key_sym;
-            char s[80];
-            int has_ch;
-
-            has_ch = XLookupString(&(input.xkey), s, sizeof(s), &key_sym,
-               &c_stat);
-            TranslateKeys(s, &key_sym);
-            if (CharIsESC(&(input.xkey), s, key_sym, &has_ch)) {
+            if (KeyPressEventIsEscape(&input.xkey)) {
                XUngrabPointer(mainDisplay, CurrentTime);
                HighLightInContinueArc(drawing_arc, OrigX, OrigY, saved_x,
                      saved_y, ltx, lty, &w, &h, angle1, angle2, &dx, &dy,
