@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/attr.c,v 4.27 2000/04/15 19:15:40 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/attr.c,v 4.33 2000/08/21 12:37:35 william Exp $
  */
 
 #define _INCLUDE_FROM_ATTR_C_
@@ -253,7 +253,7 @@ void DelAllAttrs(AttrPtr)
 
    for (ptr=AttrPtr; ptr != NULL; ptr=next_attr) {
       next_attr = ptr->next;
-      FreeTextObj(ptr->obj);
+      FreeObj(ptr->obj);
       FreeAttr(ptr);
    }
 }
@@ -303,6 +303,7 @@ struct AttrRec *AddAttrByNameAndValue(ObjPtr, AttrName, AttrValue)
    pStrSeg->asc = canvasFontAsc;
    pStrSeg->des = canvasFontDes;
    pStrSeg->direction = canvasFontDirection;
+   pStrSeg->dontreencode = canvasFontDontReencode;
    pStrSeg->double_byte = canvasFontDoubleByte;
    pStrSeg->double_byte_mod_bytes = canvasFontDoubleByteModBytes;
    pStrSeg->double_byte_vertical = canvasFontDoubleByteVertical;
@@ -1490,7 +1491,6 @@ int HasEditAttrsInContextMenu(obj_ptr, pp_name_attr)
    return FALSE;
 }
 
-static
 void FreeRestrictedAttrNames(ppsz_restricted, num_restricted)
    char **ppsz_restricted;
    int num_restricted;
@@ -1507,7 +1507,6 @@ void FreeRestrictedAttrNames(ppsz_restricted, num_restricted)
    }
 }
 
-static
 void GetRestrictedAttrNames(restricted_attr_obj, pppsz_restricted,
       pn_num_restricted)
    struct ObjRec *restricted_attr_obj;
@@ -1560,7 +1559,6 @@ void GetRestrictedAttrNames(restricted_attr_obj, pppsz_restricted,
    }
 }
 
-static
 int IsRestrictedAttr(attr_name, ppsz_restricted, num_restricted)
    char *attr_name, **ppsz_restricted;
    int num_restricted;
@@ -1696,7 +1694,7 @@ void MoveAttr()
       char *tmp_buf=NULL;
       MiniLinesInfo *minilines=(&attr_ptr1->obj->detail.t->minilines);
 
-      tmp_buf = ConvertMiniLineToString(minilines->first,
+      tmp_buf = ConvertAttrNameFirstMiniLineToString(attr_ptr1,
             &need_to_free_tmp_buf);
       if ((attr_strings[i]=UtilStrDup(tmp_buf)) == NULL) FailAllocMessage();
 
@@ -2100,7 +2098,6 @@ int EditAttrNames(TopStr, ObjAttrDspList, entries, num_entries, pCheckArray)
    return (Names(win_name, NULL, NULL, 0, NULL)==BUTTON_OK);
 }
 
-static
 int BlankStr(s)
    char *s;
 {
