@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/color.c,v 4.37 2000/05/15 22:30:33 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/color.c,v 4.40 2000/08/17 20:05:49 william Exp $
  */
 
 #define _INCLUDE_FROM_COLOR_C_
@@ -165,6 +165,19 @@ int GetDrawingFgPixel(index, pixel)
    }
 }
 
+void GetDrawingFgColorStr(index, pixel, color_buf, buf_sz)
+   int index, pixel, buf_sz;
+   char *color_buf;
+{
+   if (index != INVALID && index != BACKPAT) {
+      UtilStrCpyN(color_buf, buf_sz, colorMenuItems[index]);
+   } else if (myFileBgColorStr == NULL || myFileFgColorStr == NULL) {
+      UtilStrCpyN(color_buf, buf_sz, myFgColorStr);
+   } else {
+      UtilStrCpyN(color_buf, buf_sz, myFileFgColorStr);
+   }
+}
+
 struct LocalColorRec {
    char *name, *spec;
    int len;
@@ -1715,7 +1728,7 @@ void HandleMotionInColorWindow(motion_ev)
 
                sprintf(left_str, TgLoadString(colorLayerOn[i] ?
                      STID_TURN_COLOR_LAYER_NUM_OFF :
-                     STID_TURN_COLOR_LAYER_NUM_OFF),
+                     STID_TURN_COLOR_LAYER_NUM_ON),
                      colorMenuItems[i], i);
                sprintf(right_str, TgLoadCachedString(CSTID_SET_COLOR_TO),
                      colorMenuItems[i]);
