@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/eps.c,v 4.22 2000/05/20 22:36:13 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/eps.c,v 4.28 2000/08/07 19:59:55 william Exp $
  */
 
 #define _INCLUDE_FROM_EPS_C_
@@ -465,9 +465,9 @@ int ErrorInConvertTiffToXbm(fp, tiff_fp, xbm_fp, fname)
 }
 
 static
-int ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname)
+int ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname, xbm_sz)
    FILE *fp;
-   int tiff_offset, tiff_sz;
+   int tiff_offset, tiff_sz, xbm_sz;
    char *xbm_fname;
 {
    FILE *tiff_fp=NULL, *xbm_fp=NULL, *pfp;
@@ -481,9 +481,7 @@ int ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname)
       return ErrorInConvertTiffToXbm(fp, NULL, NULL, NULL);
    }
    /* do not translate -- program constants */
-   sprintf(tiff_fname, "%sTgifXXXXXX", TMP_DIR);
-   mktemp(tiff_fname);
-   unlink(tiff_fname);
+   MkTempFile(tiff_fname, sizeof(tiff_fname), tmpDir, TOOL_NAME);
    if ((tiff_fp=fopen(tiff_fname, "w")) == NULL) {
       return ErrorInConvertTiffToXbm(fp, NULL, NULL, NULL);
    }
@@ -503,9 +501,7 @@ int ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname)
    tiff_fp = NULL;
 
    /* convert TIFF to XBM */
-   sprintf(xbm_fname, "%sTgifXXXXXX", TMP_DIR);
-   mktemp(xbm_fname);
-   unlink(xbm_fname);
+   MkTempFile(xbm_fname, sizeof(xbm_fname), tmpDir, TOOL_NAME);
    if ((xbm_fp=fopen(xbm_fname, "w")) == NULL) {
       return ErrorInConvertTiffToXbm(fp, NULL, NULL, NULL);
    }
@@ -556,10 +552,10 @@ FILE *ErrorInGetTiffEPSIInfo(fp, eps_fp, fname)
 }
 
 static
-FILE *GetTiffEPSIInfo(fp, pszEPS, pnPreviewOK)
+FILE *GetTiffEPSIInfo(fp, pszEPS, file_buf_sz, pnPreviewOK)
    FILE *fp;
    char *pszEPS;
-   int *pnPreviewOK;
+   int file_buf_sz, *pnPreviewOK;
 {
    int bytes_to_read=0x1e, tiff_sz, tiff_offset, eps_sz;
    int need_to_check_ps=TRUE;
@@ -582,7 +578,8 @@ FILE *GetTiffEPSIInfo(fp, pszEPS, pnPreviewOK)
          FILE *xbm_fp=NULL;
          int bytes_read=0;
 
-         *pnPreviewOK = ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname);
+         *pnPreviewOK = ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname,
+               sizeof(xbm_fname));
          if (fseek(fp, 0x1e, SEEK_SET) != 0) {
             return ErrorInGetTiffEPSIInfo(fp, NULL, NULL);
          }
@@ -612,13 +609,12 @@ FILE *GetTiffEPSIInfo(fp, pszEPS, pnPreviewOK)
          }
       }
    } else {
-      *pnPreviewOK = ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname);
+      *pnPreviewOK = ConvertTiffToXbm(fp, tiff_offset, tiff_sz, xbm_fname,
+            sizeof(xbm_fname));
       if (fseek(fp, 0x1e, SEEK_SET) != 0) {
          return ErrorInGetTiffEPSIInfo(fp, NULL, NULL);
       }
-      sprintf(pszEPS, "%sTgifXXXXXX", TMP_DIR);
-      mktemp(pszEPS);
-      unlink(pszEPS);
+      MkTempFile(pszEPS, file_buf_sz, tmpDir, TOOL_NAME);
       if ((eps_fp=fopen(pszEPS, "w")) == NULL) {
          return ErrorInGetTiffEPSIInfo(fp, NULL, NULL);
       }
@@ -693,16 +689,15 @@ void GetEPSFullPath(file_name, full_path, buf_sz)
 }
 
 static
-int ConvertPsToXbm(pszPsPath, pszXbmPath)
+int ConvertPsToXbm(pszPsPath, pszXbmPath, file_buf_sz)
    char *pszPsPath, *pszXbmPath;
+   int file_buf_sz;
 {
    FILE *pFile=NULL, *pPipe=NULL;
    char *pszCmd=NULL, szBuf[MAXSTRING];
    int bytes_read=0;
 
-   sprintf(pszXbmPath, "%sTgifXXXXXX", TMP_DIR);
-   mktemp(pszXbmPath);
-   unlink(pszXbmPath);
+   MkTempFile(pszXbmPath, file_buf_sz, tmpDir, TOOL_NAME);
    pszCmd = (char*)malloc(
          (strlen(psToXbmCmd)+strlen(pszPsPath)+10)*sizeof(char));
    if (pszCmd == NULL) {
@@ -758,13 +753,12 @@ int AutoGeneratePreviewBitmap(pszPsPath, pBitmap, pImage, pnImageW, pnImageH)
    char xbm_fname[MAXPATHLENGTH+1];
    unsigned int tmp_w=0, tmp_h=0;
    int rc=0, x_hot=0, y_hot=0, empty_image=FALSE, dont_free_orig_bitmap=FALSE;
-   Pixmap orig_bitmap=None, bitmap=None;
-   XImage *image=NULL;
+   Pixmap orig_bitmap=None;
 
    SetWatchCursor(drawWindow);
    SetWatchCursor(mainWindow);
    SaveStatusStrings();
-   rc = ConvertPsToXbm(pszPsPath, xbm_fname);
+   rc = ConvertPsToXbm(pszPsPath, xbm_fname, sizeof(xbm_fname));
    RestoreStatusStrings();
    SetDefaultCursor(mainWindow);
    ShowCursor();
@@ -829,11 +823,11 @@ int DoMyReadEPSFile(file_name, pn_image_w, pn_image_h, p_bitmap, p_image,
    float llx=0.0, lly=0.0, urx=0.0, ury=0.0;
 
    if (!cmdLineDosEpsFilter) {
-      *pn_image_w = *pn_image_h = *pn_num_lines = *pn_epsf_level = 0;
+      *pn_image_w = *pn_image_h = *pn_epsf_level = 0;
       *p_bitmap = None;
       *p_image = NULL;
-      *pn_num_lines = 0;
-      *ppsz_epsflines = NULL;
+      if (pn_num_lines != NULL) *pn_num_lines = 0;
+      if (ppsz_epsflines != NULL) *ppsz_epsflines = NULL;
       *pn_epsf_level = 0;
       *pf_llx = llx; *pf_lly = lly; *pf_urx = urx; *pf_ury = ury;
       *psz_write_date = '\0';
@@ -856,7 +850,7 @@ int DoMyReadEPSFile(file_name, pn_image_w, pn_image_h, p_bitmap, p_image,
             free(line);
             if (cmdLineDosEpsFilter) {
                if ((fp=GetTiffEPSIInfo(fp, tiff_eps_fname,
-                     &tiff_preview_ok)) == NULL) {
+                     sizeof(tiff_eps_fname), &tiff_preview_ok)) == NULL) {
                   sprintf(gszMsgBox,
                         TgLoadString(STID_FAIL_TO_PARSE_WINEPS_FILE),
                         real_fname);
@@ -873,7 +867,7 @@ int DoMyReadEPSFile(file_name, pn_image_w, pn_image_h, p_bitmap, p_image,
                fp = NULL;
                return BitmapSuccess;
             } else if ((fp=GetTiffEPSIInfo(fp, tiff_eps_fname,
-                  &tiff_preview_ok)) == NULL ||
+                  sizeof(tiff_eps_fname), &tiff_preview_ok)) == NULL ||
                   (line=UtilGetALine(fp)) == NULL) {
                sprintf(gszMsgBox,
                      TgLoadString(STID_FAIL_TO_PARSE_WINEPS_FILE), real_fname);
@@ -1071,13 +1065,17 @@ int DoMyReadEPSFile(file_name, pn_image_w, pn_image_h, p_bitmap, p_image,
       *pn_image_h = image_h;
       *p_bitmap = bitmap;
       *p_image = image;
-      *pn_num_lines = numLines;
-      *ppsz_epsflines = (char**)malloc(numLines*sizeof(char*));
-      if (*ppsz_epsflines == NULL) FailAllocMessage();
-
+      if (pn_num_lines != NULL) *pn_num_lines = numLines;
+      if (ppsz_epsflines != NULL) {
+         *ppsz_epsflines = (char**)malloc(numLines*sizeof(char*));
+         if (*ppsz_epsflines == NULL) FailAllocMessage();
+      }
       for (i=0, line_ptr=topLine; line_ptr != NULL; line_ptr = next_line, i++) {
          next_line = line_ptr->next;
-         (*ppsz_epsflines)[i] = UtilStrDup(line_ptr->s);
+         if (ppsz_epsflines != NULL) {
+            (*ppsz_epsflines)[i] = UtilStrDup(line_ptr->s);
+            if ((*ppsz_epsflines)[i] == NULL) FailAllocMessage();
+         }
          free(line_ptr->s);
          free(line_ptr);
       }
@@ -1115,9 +1113,10 @@ int MyReadEPSFile(file_name, image_w, image_h, bitmap, image, num_lines,
 }
 
 static
-FILE *JustGetTiffEPSIInfo(fp, pszEPS)
+FILE *JustGetTiffEPSIInfo(fp, pszEPS, file_buf_sz)
    FILE *fp;
    char *pszEPS;
+   int file_buf_sz;
 {
    int bytes_to_read=0x1e, eps_sz, need_to_check_ps=TRUE;
    char buf[0x20];
@@ -1133,15 +1132,12 @@ FILE *JustGetTiffEPSIInfo(fp, pszEPS)
    }
    eps_sz = ReadDoubleWord(&buf[0x08]);
 
-   sprintf(pszEPS, "%sTgifXXXXXX", TMP_DIR);
-   mktemp(pszEPS);
-   unlink(pszEPS);
+   MkTempFile(pszEPS, file_buf_sz, tmpDir, TOOL_NAME);
    if ((eps_fp=fopen(pszEPS, "w")) == NULL) {
       fclose(fp);
       unlink(pszEPS);
       return NULL;
    }
-
    /* copy the EPS content from the original file to the new EPS file */
    while (eps_sz > 0) {
       bytes_to_read = min(eps_sz, sizeof(gszMsgBox));
@@ -1184,7 +1180,7 @@ int JustReadEPSLines(xbm_ptr)
    char *c_ptr, *line, loc_time[MAXSTRING+1];
    char tiff_eps_fname[MAXPATHLENGTH+1];
    char real_fname[MAXPATHLENGTH+1];
-   int first_line=TRUE;
+   int first_line=TRUE, propagated_eps_status=INVALID;
    int boundingbox_found=FALSE, preview_found=FALSE, found;
    int boundingbox_atend=FALSE;
    float llx, lly, urx, ury;
@@ -1231,7 +1227,8 @@ int JustReadEPSLines(xbm_ptr)
                line[2] == ((char)0xd3) && line[3] == ((char)0xc6) &&
                line[4] == ((char)0x1e)) {
             free(line);
-            if ((fp=JustGetTiffEPSIInfo(fp, tiff_eps_fname)) == NULL ||
+            if ((fp=JustGetTiffEPSIInfo(fp, tiff_eps_fname,
+                  sizeof(tiff_eps_fname))) == NULL ||
                   (line=UtilGetALine(fp)) == NULL) {
                if (fp != NULL) fclose(fp);
                if (*tiff_eps_fname != '\0') unlink(tiff_eps_fname);
@@ -1248,6 +1245,7 @@ int JustReadEPSLines(xbm_ptr)
          }
          AddLine(line);
          need_to_free_line = FALSE;
+         propagated_eps_status = INVALID;
       } else if ((!boundingbox_found || boundingbox_atend) &&
             strncmp(line, "%%BoundingBox:", 14) == 0) {
          if (sscanf(&(line[14]), "%f %f %f %f", &llx, &lly, &urx, &ury) == 4) {
@@ -1258,6 +1256,7 @@ int JustReadEPSLines(xbm_ptr)
                boundingbox_atend = TRUE;
             }
          }
+         propagated_eps_status = INVALID;
       } else if (!preview_found && strncmp(line, "%%BeginPreview:", 15) == 0) {
          char *preview_line;
 
@@ -1286,14 +1285,21 @@ int JustReadEPSLines(xbm_ptr)
             CleanUpLines();
             return FALSE;
          }
+         propagated_eps_status = INVALID;
+      } else if (line[0] == '%' && line[1] == '%' && line[2] != '%') {
+         /* Actaully, need to check DCS conformance! */
+         if (propagated_eps_status != INVALID && line[2] != '+') {
+            propagated_eps_status = INVALID;
+         }
+         UpdatePropagatedEPSInfo(line, &propagated_eps_status);
       } else {
-         if (line[0] == '%' && line[1] == '!') (xbm_ptr->epsf_level)++;
-         if (line[0] == '%' && line[1] == '%' && line[2] != '%') {
-            /* Actaully, need to check DCS conformance! */
+         if (line[0] == '%' && line[1] == '!') {
+            (xbm_ptr->epsf_level)++;
          } else if (!stripEPSComments || line[0] != '%') {
             AddLine(line);
             need_to_free_line = FALSE;
          }
+         propagated_eps_status = INVALID;
       }
       if (need_to_free_line) free(line);
    }
@@ -1351,7 +1357,7 @@ void DumpEPSObj(FP, ObjPtr)
    float w_psu, h_psu, bbox_w_psu, bbox_h_psu, dx_psu, dy_psu, ltx_psu, rby_psu;
    struct XBmRec *xbm_ptr=ObjPtr->detail.xbm;
    struct MtrxRec mtrx;
-   int no_rotate=(ObjPtr->ctm==NULL);
+   int no_rotate=(ObjPtr->ctm==NULL), need_to_free_epsflines=FALSE;
          /* (ObjPtr->ctm->m[CTM_SIN]== 0 && ObjPtr->ctm->m[CTM_MSIN] == 0); */
 
    if (!xbm_ptr->save_epsf) {
@@ -1359,6 +1365,7 @@ void DumpEPSObj(FP, ObjPtr)
          if (!JustReadEPSLines(xbm_ptr)) {
             return;
          }
+         need_to_free_epsflines = TRUE;
       } else {
          char loc_time[MAXSTRING+1], real_fname[MAXPATHLENGTH+1];
          struct stat stat_buf;
@@ -1526,6 +1533,17 @@ void DumpEPSObj(FP, ObjPtr)
    fprintf(FP, "tgiflevel%1d restore\n", xbm_ptr->epsf_level);
    fprintf(FP, "tgifdict begin\n");
    fprintf(FP, "\n");
+
+   if (need_to_free_epsflines && xbm_ptr->epsflines != NULL) {
+      for (i=0; i < xbm_ptr->num_epsf_lines; i++) {
+         if (xbm_ptr->epsflines[i] != NULL) {
+            free(xbm_ptr->epsflines[i]);
+         }
+      }
+      if (xbm_ptr->epsflines != NULL) free(xbm_ptr->epsflines);
+      xbm_ptr->num_epsf_lines = 0;
+      xbm_ptr->epsflines = NULL;
+   }
 }
 
 void SetEPSObjCTM(obj_ptr, p_orig_obbox)
@@ -1674,7 +1692,7 @@ void UpdateEPS()
          struct XBmRec *xbm_ptr, *new_xbm_ptr;
          struct ObjRec *obj_ptr, *new_obj_ptr;
          char write_date[32], **lines=NULL;
-         int rc, num_lines, epsf_level, image_w, image_h, save_epsf;
+         int rc, num_lines=0, epsf_level, image_w, image_h, save_epsf;
          int transformed;
          float llx, lly, urx, ury;
          Pixmap bitmap;
@@ -1690,7 +1708,8 @@ void UpdateEPS()
          SetWatchCursor(drawWindow);
          SetWatchCursor(mainWindow);
          rc = MyReadEPSFile(xbm_ptr->filename, &image_w, &image_h, &bitmap,
-               &image, &num_lines, &lines, &epsf_level, &llx, &lly, &urx, &ury,
+               &image, (save_epsf ? &num_lines : NULL),
+               (save_epsf ? &lines : NULL), &epsf_level, &llx, &lly, &urx, &ury,
                write_date);
          SetDefaultCursor(mainWindow);
          ShowCursor(); 
@@ -1710,6 +1729,14 @@ void UpdateEPS()
                write_date);
          saveEPSLines = FALSE;
 
+         if (!save_epsf && lines != NULL) {
+            int i=0;
+
+            for (i=0; i < num_lines; i++) {
+               if (lines[i] != NULL) free(lines[i]);
+            }
+            free(lines);
+         }
          new_obj_ptr->x = obj_ptr->x;
          new_obj_ptr->y = obj_ptr->y;
          if (transformed) {
