@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/mainmenu.c,v 4.25 2000/01/15 22:23:51 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/mainmenu.c,v 4.27 2000/07/25 20:25:23 william Exp $
  */
 
 #define _INCLUDE_FROM_MAINMENU_C_
@@ -1019,6 +1019,36 @@ void UpdateAllPinnedMenus()
    UpdatePinnedMenu(MENU_MAIN);
 }
 
+void UseWireMenuItemInModeItem(connecting)
+   int connecting;
+{
+   Window win=subMenuInfo[MENU_MODE].win;
+
+   if (win != None) {
+      int extra_win_info_index=subMenuInfo[MENU_MODE].extra_index;
+
+      if (extra_win_info_index >= 0 && extra_win_info_index < numExtraWins &&
+            extraWinInfo[extra_win_info_index].window == win) {
+         TgMenu *menu=(TgMenu*)(extraWinInfo[extra_win_info_index].userdata);
+
+         if (menu != NULL) {
+            TgMenuItem stMenuItem;
+
+            memset(&stMenuItem, 0, sizeof(TgMenuItem));
+            if (connecting) {
+               stMenuItem.menu_str = (char*)(&wireBitmap);
+            } else {
+               stMenuItem.menu_str = (char*)(&choicePixmap[DRAWPOLY]);
+            }
+            if (!TgSetMenuItemInfo(&menu->menuitems[DRAWPOLY],
+                  TGMU_MASK_MENUSTR, &stMenuItem)) {
+            }
+            return;
+         }
+      }
+   }
+}
+
 void DestroyPinnedMenu(menu_index)
    int menu_index;
 {
