@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/msg.c,v 4.44 2000/05/10 19:20:44 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/msg.c,v 4.46 2000/08/28 16:49:23 william Exp $
  */
 
 #define _INCLUDE_FROM_MSG_C_
@@ -1398,6 +1398,7 @@ void Usage(tool_name)
    fprintf(stderr, "\t[-print_cmd \"<command>\"] \\\n");
    fprintf(stderr, "\t[-one_file_per_page] \\\n");
    fprintf(stderr, "\t[-pepsc] \\\n");
+   fprintf(stderr, "\t[-nolandpdfspd] \\\n");
    fprintf(stderr, "\t[-dontcondense | -condensed] \\\n");
    fprintf(stderr, "\t[-a4] \\\n");
    fprintf(stderr, "\t[-bop_hook \"<string>\"] \\\n");
@@ -1549,6 +1550,8 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
             whereToPrint = cmdLineWhereToPrint = PDF_FILE;
          } else if (strcmp(*argv, "-text") == 0) {
             whereToPrint = cmdLineWhereToPrint = TEXT_FILE;
+         } else if (strcmp(*argv, "-netlist") == 0) {
+            whereToPrint = cmdLineWhereToPrint = NETLIST_FILE;
          } else if (strcmp(*argv, "-raw") == 0) {
             cmdLineDumpURL = TRUE;
             cmdLineDumpURLWithHeader = FALSE;
@@ -1587,6 +1590,8 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
             cmdLineOneFilePerPage = TRUE;
          } else if (strcmp(*argv, "-pepsc") == 0) {
             stripEPSComments = FALSE;
+         } else if (strcmp(*argv, "-nolandpdfspd") == 0) {
+            cmdLineNoLandscapePdfSetPageDevice = TRUE;
          } else if (strcmp(*argv, "-dontcondense") == 0) {
             SetCmdLineDontCondense();
          } else if (strcmp(*argv, "-condensed") == 0) {
