@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/oval.c,v 4.12 2000/05/01 17:51:00 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/oval.c,v 4.13 2000/07/18 18:57:13 william Exp $
  */
 
 #define _INCLUDE_FROM_OVAL_C_
@@ -540,8 +540,6 @@ void MyContinueOval(d, gc, pBBox)
    MyOval(d, gc, bbox);
 }
 
-static XComposeStatus c_stat;
- 
 static
 void ContinueOval(OrigX, OrigY)
    int OrigX, OrigY;
@@ -591,14 +589,7 @@ void ContinueOval(OrigX, OrigY)
       } else if (input.type == MotionNotify || input.type == KeyPress ||
             input.type == KeyRelease) {
          if (input.type == KeyPress) {
-            KeySym key_sym;
-            char s[80];
-            int has_ch;
-
-            has_ch = XLookupString(&(input.xkey), s, sizeof(s), &key_sym,
-                  &c_stat);
-            TranslateKeys(s, &key_sym);
-            if (CharIsESC(&(input.xkey), s, key_sym, &has_ch)) {
+            if (KeyPressEventIsEscape(&input.xkey)) {
                XUngrabPointer(mainDisplay, CurrentTime);
                MyContinueOval(drawWindow, drawGC, &bbox);
                EndIntervalRulers(grid_x, grid_y);
