@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/pin.c,v 4.8 2000/01/15 22:24:03 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/pin.c,v 4.13 2000/07/26 12:56:59 william Exp $
  */
 
 #define _INCLUDE_FROM_PIN_C_
@@ -52,6 +52,8 @@
 #include "setup.e"
 #include "strtbl.e"
 
+int drawPolyToConnectPins=0;
+
 struct ObjRec *gpStartPin=NULL, *gpEndPin=NULL;
 
 static struct SelRec *topPinSel=NULL, *botPinSel=NULL;
@@ -314,8 +316,10 @@ void HandlePinHighlights(MouseX, MouseY)
          HighLightAPin(FALSE);
          if (obj_under_cursor != NULL) {
             drawPolyHighlightedNode = obj_under_cursor;
+            /* may need to call something like SetWiringNodeInfo()!? */
          } else {
             drawPolyHighlightedNode = NULL;
+            /* may need to call something like SetWiringNodeInfo()!? */
          }
          if (drawPolyHighlightedNode != NULL) {
             need_to_highlight = TRUE;
@@ -325,6 +329,7 @@ void HandlePinHighlights(MouseX, MouseY)
    } else {
       if (obj_under_cursor != NULL) {
          drawPolyHighlightedNode = obj_under_cursor;
+         /* may need to call something like SetWiringNodeInfo()!? */
          need_to_highlight = TRUE;
          something_changed = TRUE;
       }
@@ -381,8 +386,6 @@ void CreateConnection(pStartPin, pEndPin)
    AppendConnToPin(pEndPin, pEndConn, topObj);
 }
 
-static XComposeStatus c_stat;
-
 void ConnectPins()
 {
    int already_in_hyperspace=inHyperSpace, connecting=TRUE;
@@ -396,11 +399,12 @@ void ConnectPins()
    }
    MakeQuiescent();
 
+   ResetWiringNodeInfo();
    values.line_width = 3;
    XChangeGC(mainDisplay, revGrayGC, GCLineWidth, &values);
 
    SetCurChoice(DRAWPOLY);
-   drawPolyToEndInANode = 0;
+   gstWiringInfo.num_ports_to_connect = 0;
 
    while (connecting) {
       drawPolyToConnectPins = 2;
@@ -414,13 +418,7 @@ void ConnectPins()
          if (input.type == Expose) {
             ExposeEventHandler(&input, TRUE);
          } else if (input.type == KeyPress) {
-            XKeyEvent *key_ev=(&(input.xkey));
-            KeySym key_sym;
-            char s[80];
-            int has_ch=XLookupString(key_ev, s, sizeof(s), &key_sym, &c_stat);
-
-            TranslateKeys(s, &key_sym);
-            if (CharIsESC(key_ev, s, key_sym, &has_ch)) {
+            if (KeyPressEventIsEscape(&input.xkey)) {
                connecting = FALSE;
                break;
             }
@@ -442,6 +440,7 @@ void ConnectPins()
       drawPolyToConnectPins = 0;
       if (gpHighLightedPin != NULL) {
          drawPolyHighlightedNode = gpHighLightedPin;
+         /* may need to call something like SetWiringNodeInfo()!? */
          HighLightAPin(FALSE);
       }
       drawPolyHighlightedNode = gpHighLightedPin = NULL;
