@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/rcbox.c,v 4.12 2000/05/01 20:19:08 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/rcbox.c,v 4.13 2000/07/18 18:57:01 william Exp $
  */
 
 #define _INCLUDE_FROM_RCBOX_C_
@@ -574,8 +574,6 @@ void CreateRCBoxObj(X1, Y1, X2, Y2, CreateAbsolute)
    AddObj(NULL, topObj, obj_ptr);
 }
 
-static XComposeStatus c_stat;
- 
 static
 void ContinueRCBox(OrigX, OrigY)
    int OrigX, OrigY;
@@ -667,13 +665,7 @@ void ContinueRCBox(OrigX, OrigY)
          DrawIntervalRulers(OrigX, OrigY, grid_x, grid_y);
          while (XCheckMaskEvent(mainDisplay, PointerMotionMask, &ev)) ;
       } else if (input.type == KeyPress) {
-         KeySym key_sym;
-         char s[80];
-         int has_ch;
-
-         has_ch = XLookupString(&(input.xkey), s, sizeof(s), &key_sym, &c_stat);
-         TranslateKeys(s, &key_sym);
-         if (CharIsESC(&(input.xkey), s, key_sym, &has_ch)) {
+         if (KeyPressEventIsEscape(&input.xkey)) {
             XUngrabPointer(mainDisplay, CurrentTime);
             MyRCBox(drawWindow,drawGC,OrigX,OrigY,saved_x,saved_y,radius);
             EndIntervalRulers(grid_x, grid_y);
