@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/remote.c,v 4.29 2000/01/15 22:24:08 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/remote.c,v 4.34 2000/08/07 20:05:25 william Exp $
  */
 
 #define _INCLUDE_FROM_REMOTE_C_
@@ -552,13 +552,12 @@ char *WriteRemoteFileIntoTemp(psz_buf, buf_sz, psz_ext)
    char *tmp_fname=NULL;
    int fd=(-1);
 
-   tmp_fname = (char*)malloc((strlen(TMP_DIR)+20)*sizeof(char));
+   tmp_fname = (char*)malloc((strlen(tmpDir)+20)*sizeof(char));
    if (tmp_fname == NULL) {
       FailAllocMessage();
       return NULL;
    }
-   sprintf(tmp_fname, "%sTgifXXXXXX", TMP_DIR);
-   mktemp(tmp_fname);
+   MkTempFile(tmp_fname, (strlen(tmpDir)+19)*sizeof(char), tmpDir, TOOL_NAME);
    if (psz_ext != NULL) strcat(tmp_fname, psz_ext);
    unlink(tmp_fname);
    if ((fd=open(tmp_fname, O_WRONLY|O_CREAT|O_TRUNC)) == (-1)) {
@@ -2045,7 +2044,7 @@ int LoadRemoteFileFromMem(psz_url, psz_buf, psz_content_type, buf_sz, is_html)
 
    if (!rc_loadfile) {
       NewProc();
-      PasteString(psz_buf);
+      PasteString(psz_buf, TRUE, TRUE);
    }
    SetCurDir(psz_url);
    curFileDefined = TRUE;
