@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/setup.c,v 4.50 2000/05/10 19:31:26 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/setup.c,v 4.56 2000/08/04 13:30:28 william Exp $
  */
 
 #define _INCLUDE_FROM_SETUP_C_
@@ -82,6 +82,7 @@
 #include "setup.e"
 #include "shape.e"
 #include "shortcut.e"
+#include "special.e"
 #include "spline.e"
 #include "stk.e"
 #include "stretch.e"
@@ -240,6 +241,7 @@ char	drawPath[MAXPATHLENGTH]; /* last char is NOT '/' */
 char	bootDir[MAXPATHLENGTH+2];
 char	homeDir[MAXPATHLENGTH];
 char	tgifDir[MAXPATHLENGTH];
+char	tmpDir[MAXPATHLENGTH];
 
 int	symPathNumEntries = INVALID;
 char	* * symPath=NULL;
@@ -846,7 +848,7 @@ void Setup()
    int x_in_cmdline=FALSE, y_in_cmdline=FALSE, cur_y=0, i, x_offset=0;
    int bg_pixel=(-1);
    char *c_ptr=NULL;
-   int def_x_neg=0, def_y_neg=0, paper_size_set;
+   int def_x_neg=0, def_y_neg=0, paper_size_set, tmp_dir_in_x_def=FALSE;
    struct stat stat_buf;
    XWMHints wmhints;
    XSizeHints sizehints;
@@ -920,9 +922,12 @@ void Setup()
          whereToPrint = PNG_FILE;
       } else if (UtilStrICmp(c_ptr, "JPEG") == 0) {
          whereToPrint = JPEG_FILE;
+      } else if (UtilStrICmp(c_ptr, "NetList") == 0) {
+         whereToPrint = NETLIST_FILE;
       } else {
          fprintf(stderr, TgLoadString(STID_INVALID_XDEF_USE_ALT_STR),
                TOOL_NAME, "WhereToPrint", c_ptr, "EPS");
+         fprintf(stderr, "\n");
       }
    }
    useGray = FALSE;
@@ -1442,6 +1447,42 @@ void Setup()
    if (*bootDir == '\0') {
       GetWorkingDirectory(bootDir, sizeof(bootDir));
    }
+   /* do not translate -- program constants */
+   if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "TmpDir")) != NULL) {
+      UtilTrimBlanks(c_ptr);
+      if (*c_ptr == '\0') {
+         fprintf(stderr, TgLoadString(STID_INVALID_DIR_IN_X_DEFAULT),
+               c_ptr, TOOL_NAME, "TmpDir");
+         fprintf(stderr, "\n");
+      } else {
+         UtilStrCpyN(tmpDir, sizeof(tmpDir)-1, c_ptr);
+         strcat(tmpDir, DIR_SEP_STR);
+         if (UtilIsDirectory(tmpDir)) {
+            tmp_dir_in_x_def = TRUE;
+         } else {
+            fprintf(stderr, TgLoadString(STID_TMP_DIR_NOT_EXIST_USE_XDEF),
+                  tmpDir, TOOL_NAME, "TmpDir");
+            fprintf(stderr, "\n");
+         }
+      }
+   }
+   if (!tmp_dir_in_x_def) {
+#ifndef _TMP_DIR_IN_HOME_DIR
+      UtilStrCpyN(tmpDir, sizeof(tmpDir), TMP_DIR);
+      if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "TmpDirInHomeDir")) !=
+            NULL && UtilStrICmp(c_ptr, "true") == 0) {
+         UtilStrCpyN(tmpDir, sizeof(tmpDir)-1, tgifDir);
+         strcat(tmpDir, DIR_SEP_STR);
+      }
+#else /* _TMP_DIR_IN_HOME_DIR */
+      UtilStrCpyN(tmpDir, sizeof(tmpDir)-1, tgifDir);
+      strcat(tmpDir, DIR_SEP_STR);
+      if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "TmpDirInHomeDir")) !=
+            NULL && UtilStrICmp(c_ptr, "false") == 0) {
+         UtilStrCpyN(tmpDir, sizeof(tmpDir), TMP_DIR);
+      }
+#endif /* ~_TMP_DIR_IN_HOME_DIR */
+   }
    InitFonts();
 
    initialMenubarWindowH = defaultFontHeight;
@@ -1785,6 +1826,8 @@ void Setup()
    InitHtml();
    InitRecentFiles();
    InitMeasureTooltip();
+   InitPoly();
+   InitSpecial();
 
 #ifdef MAPBEFORESELECT
    XMapWindow(mainDisplay, mainWindow);
