@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/shape.c,v 4.14 2000/01/15 22:24:11 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/shape.c,v 4.15 2000/07/18 18:56:21 william Exp $
  */
 
 #define _INCLUDE_FROM_SHAPE_C_
@@ -1005,8 +1005,6 @@ void DoCursor(x, y, w, h, which)
    }
 }
 
-static XComposeStatus c_stat;
-
 static
 void ContinueCreateShape(orig_x, orig_y)
    int orig_x, orig_y;
@@ -1029,9 +1027,6 @@ void ContinueCreateShape(orig_x, orig_y)
    HighLightCreateShape(grid_x, grid_y, GENERATE, &need_to_draw);
    while (!done) {
       XEvent input, ev;
-      KeySym key_sym;
-      char s[80];
-      int has_ch;
 
       XNextEvent(mainDisplay, &input);
       switch (input.type) {
@@ -1064,9 +1059,7 @@ void ContinueCreateShape(orig_x, orig_y)
          while (XCheckMaskEvent(mainDisplay, PointerMotionMask, &ev)) ;
          break;
       case KeyPress:
-         has_ch = XLookupString(&(input.xkey), s, sizeof(s), &key_sym, &c_stat);
-         TranslateKeys(s, &key_sym);
-         if (CharIsESC(&(input.xkey), s, key_sym, &has_ch)) {
+         if (KeyPressEventIsEscape(&input.xkey)) {
             done = TRUE;
          }
          break;
