@@ -29,7 +29,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/tangram2.c,v 4.17 2000/04/18 00:27:53 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/tangram2.c,v 4.18 2000/08/11 19:59:54 william Exp $
  */
 
 #define _INCLUDE_FROM_TANGRAM2_C_
@@ -62,14 +62,6 @@
 static TgMenuItemInfo tangram2MenuItemInfo[] = {
    { "About Tangram-II", NULL, "Information about Tangram-II", NULL,
      CMDID_ABOUT_TANGRAM2 },
-   { "Generate Markov Chain", NULL, "Generate Markov Chain", NULL,
-     CMDID_TANGRAM2_GENERATE_CHAIN },
-   { "Start Simulator", NULL, "Start Simulation", NULL,
-     CMDID_TANGRAM2_START_SIMULATOR },
-   { "Simulation Step", NULL, "Simulation Step", NULL,
-     CMDID_TANGRAM2_SIMULATION_STEP },
-   { "End Simulator", NULL, "End Simulation", NULL,
-     CMDID_TANGRAM2_END_SIMULATOR },
    { NULL, NULL, NULL, NULL, INVALID }
 };
 TgMenuInfo tangram2MenuInfo={ TGMUTYPE_TEXT, tangram2MenuItemInfo,
@@ -824,8 +816,6 @@ static char *StartSimulatorExec[] = {
  "exec(__GENERATE_CHAIN__.write_model);"
  "exec(__GENERATE_CHAIN__.write_global_rewards);"
  "exec(__GENERATE_CHAIN__.write_indep_chains);",
- "strcpy(command, \"gramatica $(file_name) $(__GENERATE_CHAIN__.basename) $(__GENERATE_CHAIN__.dbglevel) -nomaxcheck > $(__GENERATE_CHAIN__.output)\");",
- "launch(command);",
  "if(\"$(Mode)\"==\"I\",set_mode_I,NULL);",
  "if(\"$(Mode)\"==\"B\",set_mode_B,NULL);",
  "enable_undo();",
