@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/tgif.c,v 4.23 2000/01/15 22:24:21 william Exp $
+ * @(#)$Header: /mm/src/tgif/v4/RCS/tgif.c,v 4.26 2000/08/25 03:43:12 william Exp $
  */
 
 #define _INCLUDE_FROM_TGIF_C_
@@ -39,6 +39,7 @@
 #include "dialog.e"
 #include "exec.e"
 #include "file.e"
+#include "font.e"
 #include "grid.e"
 #include "mainloop.e"
 #include "msg.e"
@@ -334,6 +335,7 @@ void DoPrTgif(argc, argv, from_prtgif)
       argc--; argv++;
    }
    InitPaperSize();
+   if (PRTGIF && !cmdLineOpenDisplay) InitDontReencode(NULL);
    if (argc <= 0) {
       if (cmdLineStdOut) {
          fprintf(stderr, "\n%s\n",
@@ -350,6 +352,7 @@ void DoPrTgif(argc, argv, from_prtgif)
             if (cmdLineDumpURL) {
                UrlDump(inbuf);
             } else if (cmdLineDosEpsFilter) {
+               UtilStrCpyN(cmdLineOpenFile, sizeof(cmdLineOpenFile), inbuf);
                DosEpsFilter(inbuf);
             } else {
                if (cmdLineOpenDisplay) {
@@ -383,6 +386,7 @@ void DoPrTgif(argc, argv, from_prtgif)
             }
             break;
          } else if (cmdLineDosEpsFilter) {
+            UtilStrCpyN(cmdLineOpenFile, sizeof(cmdLineOpenFile), *argv);
             DosEpsFilter(*argv);
             if (argc > 1) {
                fprintf(stderr, "%s\n",
